@@ -192,6 +192,11 @@ class D4Client(object):
                         continue
                     else:
                         sys.exit(1)
+                except socket.timeout:
+                    logger.error('Connection to {}:{} timeout'.format(host, self.port))
+                    if self.reconnect:
+                        time.sleep(10)
+                        continue
                 except ssl.SSLError as e:
                     logger.error(e)
                     sys.exit(1)
@@ -289,6 +294,7 @@ class D4Client(object):
                 self.client_socket.send(d4_packet)
             except Exception as e:
                 if self.reconnect:
+                    logger.error(f'SEND D4 packet: {e}')
                     time.sleep(10)
                     self.connect()
                     self.send_d4_packet(d4_packet)
